# CERN BE-CO-HT Continuous Integration (CI) for OHWR infrastructure project

## Purpose of this repository

This repository has been created to serve two purposes:

- to provide a "user manual" for developers that want to use the OHWR
  Continuous Integration (CI) system put in place by the BE-CEM-EDL
  section at CERN;

- and to provide its member list to maintain control of software the
  licence of which only authorises its use by developers employed by
  (or affiliated with) CERN.


## OHWR CI infrastructure

The CI infrastructure is a local server machine "cispace.cern.ch"
placed in the lab. The technical specifications of this machine are:
2TB of SSD storage, 128GB of RAM.

A number of runners can be used. Some of those only use open-source
SW, others also use proprietary SW that uses CERN licences. CERN-based
users are added as members of the repository at hand (which is
otherwise public); those runners that give access to proprietary SW
first run a check, that the user that has launched the CI job is
indeed a member of this here repository, to confirm that they (the
user) have the necessary rights to launch the SW.

**Note:** When a user that is not employed by / affiliated with CERN
          launches a job that uses propritary SW, it will launch but
          it will fail (before it can execute anything). Users are
          kindly urged to check (twice) before launching a run that
          may use any software they're not licensed to use to reduce
          those failed jobs; these failures would detract from the
          experience and usefuleness of CI – imagine getting e-mail
          notifications that a bunch of CI jobs have failed, only to
          discover that this was the reason why.


## How to add a runner to your project

**Note:** You need to have at least maintainer access to a project to
          be able to add a runner to it. In addition, you need to have
          access to the server machine.

At the "Settings" → "CI/CD" page go to the "Runners" section and click
"Expand". There, you will see the available runners at the "Specific
Runners" (CERN-licensed runners) and "Shared Runners" sections. Find
the runner your project needs and click on the little "Enable for this
project" button. That's it, now in order for the runner to be used to
run a job, (at least) one of that runner's tags needs to be added to
the job.


## Runners: Open-Source

### ubuntu-python3

This runner is based on Ubuntu 18.04, and it features a Python 3.6.9
installation with pip; these are very common, so they shouldn't have
to be installed every time. However, the user can launch an `apt-get
update && apt-get upgrade` if they feel it's important that they use
the absolute latest versions from Ubuntu 18.04. Hdlmake also included.


### armv6m-gcc-llvm-coast

This runner is based on Ubuntu 18.10; It has a GCC cross-compiler for
armv6m processors, an LLVM+Clang toolchain, and the
[COAST](https://coast-compiler.readthedocs.io/en/latest/) passes
installed.


### wrs_sw_runner

This one is based on Ubuntu 18.10, some dependencies used for building
the White Rabbit Switch SW are pre-installed.


### more to be added soon!

## Runners: Proprietary

All the following runners also include hdlmake 3.3, cheby and wbgen2.


### xilinx-ise

An installation of Xilinx ISE 14.7 – minus EDK. The job script needs
to source the `~/setup_ise.sh` script first.


### xilinx-vivado

An installation of Xilinx Vivado 2018.3 and Xilinx Vivado 2019.2.
The job script needs to source the `~/setup_vivado.sh` script first.


### altera-quartus

An installation of Altera (now Intel) Quartus 16.0. The job script
needs to source the `source ~/setup_intel.sh` script first.


### mentor-modelsim

An installation of Mentor Modelsim 10.2c. The job script needs to
source the `~/setup_modelsim.sh` script first. Pre-compiled ISE
simulation libraries and a `modelsim.ini` file to load them can be
found in the `/opt/compiled_libs_ise14.7` directory.

### mentor-questasim

An installation of Mentor Questasim 10.5c. The job script needs to
source the `~/setup_questasim.sh` script first. Like the Modelsim
runner, pre-compiled ISE simulation libraries and a `modelsim.ini`
file to load them can be found in the `/opt/compiled_libs_ise14.7`
directory.


### more to be added soon!
